@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 2002 Queen of England
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,16 +20,22 @@
 #define GETVT_H
 
 /* gets an argument we should pass to the X server, on
- * linux for example we get the first empty vt (higher
- * then or equal to GdmFirstVT) and then return vt<number>
+ * linux for example we get the first empty vt (higher than
+ * or equal to GDM_KEY_FIRST_VT) and then return vt<number>
  * (e.g. "vt7") as a newly allocated string.
  * Can return NULL if we can't figure out what to do
- * or if GdmVTAllocation is false. */
+ * or if GDM_KEY_VT_ALLOCATION is false. */
 /* fd is opened so that we are saying we have opened this
  * vt.  This should be closed after the server has started.
  * This is to avoid race with other stuff openning this vt.
  * It can be set to -1 if nothing could be opened. */
-char * gdm_get_empty_vt_argument (int *fd, int *vt);
-void gdm_change_vt (int vt);
+char *	gdm_get_empty_vt_argument	(int *fd,
+					 int *vt);
+
+/* Change to the specified virtual terminal */
+void	gdm_change_vt			(int vt);
+
+/* Get the current virtual terminal number or -1 if we can't */
+int	gdm_get_cur_vt			(void);
 
 #endif /* GETVT_H */
